@@ -19,8 +19,8 @@
 ;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 ;; USA
 
-;; Package-Version: 20251111.948
-;; Package-Revision: 3b11dd8ac7eb
+;; Package-Version: 20260207.411
+;; Package-Revision: 36e5d5194bfc
 ;; Author: Sibi Prabakaran
 ;; Keywords: just justfile tools processes
 ;; URL: https://github.com/psibi/justl.el
@@ -510,7 +510,7 @@ They are returned as objects, as per the JSON output of \"just --dump\"."
 
 (defun justl-completion-annotation (candidate)
   "Annotation function for `justl-exec-recipe-in-dir'."
-  (let* ((recipes justl--recipes)
+  (let* ((recipes (buffer-local-value 'justl--recipes (window-buffer (minibuffer-selected-window))))
          (doc (cl-some
                (lambda (recipe)
                  (when (string= (justl--recipe-name recipe) candidate)
